# yaroslavslogger/greetings.py

import ctypes
import os

def say_hello(name):
    # Определяем путь к текущей директории, где находится модуль
    current_dir = os.path.dirname(__file__)

    # Путь к библиотеке будет внутри пакета, а не на уровне выше
    if os.name == 'nt':  # Для Windows
        lib_path = os.path.join(current_dir, "compiled_libraries", "string_length.dll")
    else:  # Для Linux и macOS
        lib_path = os.path.join(current_dir, "compiled_libraries", "libstring_length.so")

    # Проверяем, существует ли библиотека по указанному пути
    if not os.path.exists(lib_path):
        raise FileNotFoundError(f"Library not found: {lib_path}")

    # Загружаем библиотеку
    lib = ctypes.CDLL(lib_path)

    # Определяем аргументы и возвращаемый тип функции
    lib.string_length.argtypes = [ctypes.c_char_p]
    lib.string_length.restype = ctypes.c_int

    # Преобразуем Python-строку в байты для C
    name_bytes = name.encode('utf-8')

    # Вызываем C-функцию
    length = lib.string_length(name_bytes)

    # Возвращаем результат
    return f"Hello, {name}! Your name has {length} characters."




import logging
import logging.handlers


def init_log(file_name, level=3, console=True):
    if level > 4: level = 4
    loglev = [logging.CRITICAL, logging.ERROR, logging.WARNING, logging.INFO, logging.DEBUG]
    logger = logging.getLogger()
    logger.setLevel(logging.DEBUG)
    formatter = logging.Formatter('%(asctime)s - %(levelname)s - %(message)s')
    log_file = file_name
    fh = logging.handlers.WatchedFileHandler(log_file)
    fh.setLevel(loglev[level])
    fh.setFormatter(formatter)
    logger.addHandler(fh)
    rh = logging.handlers.RotatingFileHandler(file_name, maxBytes=100000000, backupCount=16)
    logger.addHandler(rh)
    if console:
        ch = logging.StreamHandler()
        ch.setLevel(loglev[level])
        ch.setFormatter(formatter)
        logger.addHandler(ch)




from setuptools import setup, find_packages

setup(
    name='yaroslavslogger',
    version='0.8.0',
    author='Your Name',
    author_email='your.email@example.com',
    description='A simple package with a greeting function',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='',
    packages=find_packages(),
    include_package_data=True,
    package_data={
        '': ['compiled_libraries/*.so'],
    },
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)

